@@ -1,5 +1,5 @@
-#include "iostream"
 #include "algorithm"
+#include "iostream"
 #include "vector"
 
 #ifndef suffix_tree
@@ -11,8 +11,8 @@ const int MAX_SIZE = 300;
 const int MIN_LENGTH = 3;
 const int MAX_MISMATCHES = 2;
 
-class suffix_node{
-public:
+class suffix_node {
+ public:
   int begin, nchildren, *end;
   suffix_node **children, *parent, *suffix_link;
   suffix_node(int b, int *e, suffix_node *p, suffix_node *l);
@@ -23,17 +23,18 @@ public:
   std::string get_longest_common_substring(std::string s1, std::string s2);
   std::string get_path(std::string s);
   void extend_path(int *e);
-  suffix_node* add_child(int ext, int b, int *e, suffix_node* l);
-  void add_child(suffix_node* c, int ext);
-  suffix_node* get_child(int ext);
+  suffix_node *add_child(int ext, int b, int *e, suffix_node *l);
+  void add_child(suffix_node *c, int ext);
+  suffix_node *get_child(int ext);
   bool contains_depth(int depth);
   void print(std::string s);
   bool walk_next(int &beg, int &suffix_length);
 };
 
-suffix_node* build_suffix_tree(std::string s);
+suffix_node *build_suffix_tree(std::string s);
 std::string get_reverse_complement(std::string rev_read);
 std::vector<std::string> read_adapters_from_fasta(std::string p, std::string n);
-int trim_adapter(std::string f1, std::string f2, std::string adp_path, std::string p);
+int trim_adapter(std::string f1, std::string f2, std::string adp_path,
+                 std::string p);
 
 #endif
