@@ -1,12 +1,13 @@
-#include <iostream>
 #include <fstream>
+#include <iostream>
 #include <vector>
-#include "allele_functions.h"
-#include "ref_seq.h"
-#include "htslib/vcf.h"
-#include "htslib/kstring.h"
 
-class vcf_writer{
+#include "allele_functions.h"
+#include "htslib/kstring.h"
+#include "htslib/vcf.h"
+#include "ref_seq.h"
+
+class vcf_writer {
   vcfFile *file;
   ref_antd *ref;
   bcf_hdr_t *hdr;
@@ -14,6 +15,8 @@ class vcf_writer{
   std::string sample_name;
   int write_record(uint32_t pos, std::vector<allele> &alleles, char ref);
   int init_header();
-public:
-  int init(char _mode, std::string fname, std::string region, std::string sample_name, std::string ref_path);
+
+ public:
+  int init(char _mode, std::string fname, std::string region,
+           std::string sample_name, std::string ref_path);
 };
